@@ -2,43 +2,17 @@
 which sudo || alias sudo=eval
 install_debian() {
   sudo apt-get -y update
-  sudo apt-get -y install libffi-dev libltdl7 libsoil-dev libtool make gcc automake m4 texinfo texi2html texlive-base install-info dpkg-dev debhelper yodl bison libpcre3-dev libboost-dev git g++ # yodl, bison, ... git: are for swig
-  test `lsb_release -sc` = "buster" && sudo apt-get -y install texlive-latex-base
-  sudo apt-get -y install libtool-bin
-  sudo apt-get -y install libltdl-dev
-  sudo apt-get -y install libffi-dev
-  sudo apt-get -y install autoconf-archive
-  sudo apt-get -y install libx11-dev
-  sudo apt-get -y install libx11-xcb-dev
-  sudo apt-get -y install libxrandr-dev
-  sudo apt-get -y install libxkbcommon-dev 
-  sudo apt-get -y install libgles2-mesa-dev libglew-dev
-  sudo apt-get -y install libgl1-mesa-dev
-  sudo apt-get -y install libwayland-dev wayland-protocols
-  sudo apt-get -y install libharfbuzz-dev
-  sudo apt-get -y install libvulkan-dev
-  sudo apt-get -y install libpng-dev
-  sudo apt-get -y install libwebp-dev
-  sudo apt-get -y install libfreetype6-dev
-  sudo apt-get -y install libgstreamer1.0-dev
-  sudo apt-get -y install libgstreamer-plugins-base1.0-dev
-  sudo apt-get -y install libpulse-dev
-  sudo apt-get -y install libopus-dev
-  sudo apt-get -y install libva-dev
-  sudo apt-get -y install libavcodec-dev libavutil-dev
-  sudo apt-get -y install libstb-dev
+  sudo apt-get -y -m install libffi-dev libltdl7 libsoil-dev libtool make gcc automake m4 texinfo texi2html texlive-base install-info dpkg-dev debhelper yodl bison libboost-dev g++ libpcre3-dev git # yodl, bison, ... git: are for swig
+  if ! which pcre-config >/dev/null 2>&1
+  then
+      git clone https://github.com/nektro/pcre-8.45.git
+      (cd pcre-8.45; ./configure && sed -e 's/1[.]16/1.17/g' <Makefile >Makefile.new; mv Makefile.new Makefile; make && sudo make install)
+  fi
+  test `lsb_release -sc` = "forky" && sudo apt-get -y install texlive-base texlive-latex-base
+  sudo apt-get -y -m install libtool-bin libltdl-dev libffi-dev autoconf-archive libx11-dev libx11-xcb-dev libxrandr-dev libxkbcommon-dev  libgles2-mesa-dev libglew-dev libgl1-mesa-dev libwayland-dev wayland-protocols libharfbuzz-dev libvulkan-dev libpng-dev libwebp-dev libfreetype6-dev libgstreamer1.0-dev libgstreamer-plugins-base1.0-dev libpulse-dev libopus-dev libva-dev libavcodec-dev libavutil-dev libstb-dev
   if [ `uname -m`$M32 = x86_64-m32 ]; then
     sudo apt-get -y --fix-missing install gcc-multilib
-    sudo apt-get -y install libx11-dev:i386
-    sudo apt-get -y install libgles2-mesa-dev:i386
-    sudo apt-get -y install libgl1-mesa-dev:i386
-    sudo apt-get -y install libwayland-dev:i386
-    sudo apt-get -y install libharfbuzz-dev:i386
-    sudo apt-get -y install libvulkan-dev:i386
-    sudo apt-get -y install libpng-dev:i386
-    sudo apt-get -y install libfreetype6-dev:i386
-    sudo apt-get -y install libgstreamer1.0-dev:i386
-    sudo apt-get -y install libgstreamer-plugins-base1.0-dev:i386
+    sudo apt-get -y -m install libx11-dev:i386 libgles2-mesa-dev:i386 libgl1-mesa-dev:i386 libwayland-dev:i386 libharfbuzz-dev:i386 libvulkan-dev:i386 libpng-dev:i386 libfreetype6-dev:i386 libgstreamer1.0-dev:i386 libgstreamer-plugins-base1.0-dev:i386
   fi
 }
 
@@ -107,7 +81,16 @@ install_gforth_osx() {
 }
 
 install_gforth_debian() {
-    sudo apt-get -y install gforth gforth-lib gforth-common
+    case "`lsb_release -sc`" in
+	trixie|forky)
+            wcurl https://www.complang.tuwien.ac.at/forth/gforth/gforth-0.7.3.tar.gz
+       	    tar zxf gforth-0.7.3.tar.gz
+	    BARCH=$(bash --version | grep -w bash | sed -e 's/.*(\([^ ]*\))$/\1/g')
+	    (cd gforth-0.7.3; ./configure CC=gcc-14 --prefix=/usr --host=$BARCH --build=$BARCH; make; sudo make install)
+	    ;;
+	*) sudo apt-get -y install gforth gforth-lib gforth-common
+	    ;;
+    esac
 }
 
 install_gforth_ubuntu() {
